@@ -1,23 +1,22 @@
 /*  This file was created by Configure. Any change made to it will be lost
  *  next time Configure is run. */
-#ifndef __CONFIG_H__
-#define __CONFIG_H__
+#ifndef __PARICFG_H__
+#define __PARICFG_H__
 #define UNIX
 #define GPHELP "\"/usr/bin/gphelp\""
 #define GPDATADIR "/usr/share/pari"
 #define SHELL_Q '\''
 
-#define PARIVERSION "GP/PARI CALCULATOR Version 2.7.6 (released)"
-#define PARIINFO "aarch64 running linux (portable C/GMP-6.1.0 kernel) 64-bit version"
-#define PARI_VERSION_CODE 132870
+#define PARIVERSION "GP/PARI CALCULATOR Version 2.9.0 (released)"
+#define PARIINFO "arm64 running linux (aarch64/GMP-6.1.1 kernel) 64-bit version"
+#define PARI_VERSION_CODE 133376
 #define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 #define PARI_VERSION_SHIFT 8
 #define PARI_VCSVERSION ""
 #define PARI_MT_ENGINE "pthread"
 
 #define PARI_DOUBLE_FORMAT -
-#define GCC_VERSION "gcc version 6.1.1 20160602 (GCC) "
-#define __HAS_NO_ASM__
+#define GCC_VERSION "gcc version 6.2.1 20160830 (GCC)"
 #define ASMINLINE
 
 /*  Location of GNU gzip program (enables reading of .Z and .gz files). */
@@ -30,7 +29,9 @@
 #define HAS_LOG2
 #define HAS_ISATTY
 #define HAS_ALARM
+#define HAS_SYSTEM
 #define USE_GETRUSAGE 1
+#define USE_GETTIMEOFDAY 1
 #define HAS_SIGACTION
 #define HAS_WAITPID
 #define HAS_GETENV
@@ -41,5 +42,6 @@
 #define HAS_TIOCGWINSZ
 #define HAS_STRFTIME
 #define HAS_STAT
+#define HAS_MMAP
 #define ENABLE_TLS
 #endif
